@@ -53,15 +53,9 @@ Attribute     Description
             cell_method = CellMethods(*cell_method)
             if len(cell_method) > 1:
                 raise ValueError(" e5y 6sdf ")
+
             cell_method = cell_method[0]
             self.__dict__ = cell_method[0].__dict__.copy()
-#            self._axes      = cell_method._axes       
-#            self._intervals = cell_method._intervals 
-#            self._method    = cell_method._method    
-#            self._comment   = cell_method._comment   
- #           self._where     = cell_method._where     
- #           self._within    = cell_method._within    
- #           self._over      = cell_method._over      
         else:
             self._axes      = ()
             self._intervals = ()
@@ -206,7 +200,7 @@ modified, where appropriate, to reflect netCDF variable names.
         return ' '.join(string)
     #--- End: def
 
-    def __eq__(self):
+    def __eq__(self, y):
         '''
 
 x.__eq__(y) <==> x==y
@@ -653,7 +647,6 @@ corresponding dimension or dimensions.
         _intervals = []
 
         for axis, interval in zip(self._axes, self._intervals):
-            print '--- ', axis, interval
             if axis not in axes:
                 _axes.append(axis)
                 _intervals.append(interval)
@@ -673,9 +666,7 @@ corresponding dimension or dimensions.
         if not axis_map:
             return c
 
-#        print 'c._axes =', c._axes # dch
         c._axes = tuple([axis_map.get(axis, axis) for axis in self._axes])
-#        print 'c._axes =', c._axes  # dch
 
         return c
     #--- End: def
@@ -782,13 +773,13 @@ The `!axes` attribute is ignored in the comparison.
         if intervals0:
             if not intervals1:
                 if traceback:
-                    print("{0}: Different intervals: {1!r} != {2!r}".format(
+                    print("{}: Different intervals: {!r} != {!r}".format(
                         self.__class__.__name__, self.intervals, other.intervals))
                 return False
 
             if len(intervals0) != len(intervals1):
                 if traceback:
-                    print("{0}: Different intervals: {1!r} != {2!r}".format(
+                    print("{}: Different intervals: {!r} != {!r}".format(
                         self.__class__.__name__, self.intervals, other.intervals))
                 return False
 
@@ -797,13 +788,13 @@ The `!axes` attribute is ignored in the comparison.
                                     ignore_fill_value=ignore_fill_value,
                                     traceback=traceback):
                     if traceback:
-                        print("{0}: Different intervals: {1!r} != {2!r}".format(
+                        print("{}: Different intervals: {!r} != {!r}".format(
                             self.__class__.__name__, self.intervals, other.intervals))
                     return False
      
         elif intervals1:
             if traceback:
-                print("{0}: Different intervals: {1!r} != {2!r}".format(
+                print("{}: Different intervals: {!r} != {!r}".format(
                     self.__class__.__name__, self.intervals, other.intervals))
             return False
         #--- End: if
@@ -1188,21 +1179,19 @@ x.__ne__(y) <==> x!=y
 #    #--- End: def
 
     def _parse(self, string=None, field=None):
-        '''
-
-Parse a CF cell_methods string into this `cf.CellMethods` instance in
+        '''Parse a CF cell_methods string into this `cf.CellMethods` instance in
 place.
 
 :Parameters:
 
-    string : str, optional
+    string: `str`, optional
         The CF cell_methods string to be parsed into the
         `cf.CellMethods` object. By default the cell methods will be
         empty.
 
 :Returns:
 
-    out : list
+    out: `list`
 
 :Examples:
 
@@ -1212,9 +1201,8 @@ place.
 Cell methods    : time: minimum within years
                   time: mean over years (ENSO years)
 
-'''
+        '''
         if not string:
-#            self._list[:] = []
             return []
 
         out = []
@@ -1301,7 +1289,7 @@ Cell methods    : time: minimum within years
                             intervals.append(Data(parsed_interval, units))
                         except:
                             raise ValueError(
-"Unparseable cell methods interval: {0!r}".format(
+"Unparseable cell methods interval: {!r}".format(
     interval+' '+units if units is not None else interval))
                             
                         continue
@@ -1324,8 +1312,9 @@ Cell methods    : time: minimum within years
                 if cell_methods[0].endswith(')'):
                     cell_methods.pop(0)
             #--- End: if
+
             n_intervals = len(intervals)          
-            if n_intervals > 1 and n_intervals != len(axes): #names):
+            if n_intervals > 1 and n_intervals != len(axes):
                 raise ValueError("0798798  ")
 
             cm.intervals = tuple(intervals)
