@@ -1,6 +1,4 @@
 from functools import partial as functools_partial
-from itertools import izip
-from operator import mul as mul
 
 from numpy import allclose    as numpy_allclose
 from numpy import amax        as numpy_amax
@@ -33,10 +31,27 @@ from numpy.ma import masked_where as numpy_ma_masked_where
 from numpy.ma import nomask       as numpy_ma_nomask
 from numpy.ma import where        as numpy_ma_where
 
-#from functools import partial
-
 from ..functions import broadcast_array
 
+def asanyarray(*args):
+    '''
+    '''
+    out = []
+    for x in args:
+        if not numpy_ndim(x):
+            # Make sure that we have a numpy array (as opposed to, e.g. a
+            # numpy.float64)
+            out.append(numpy_asanyarray(x))
+        else:
+            out.append(x)
+    #--- End: for
+
+    if len(out) == 1:
+        return out[0]
+    else:
+        return out
+#--- End: def
+
 def psum(x, y):
     '''
 
@@ -47,15 +62,15 @@ masked only where both input arrays are masked.
 
 :Parameters:
 
-    x : numpy array-like
-        *Might be updated in place*.
+    x: numpy array-like
+       *Might be updated in place*.
 
-    y : numpy array-like
-        Will not be updated in place.
+    y: numpy array-like
+       Will not be updated in place.
 
 :Returns:
 
-    out : numpy array
+    out: `numpy.ndarray`
 
 :Examples:
 
@@ -88,15 +103,15 @@ def pmax(x, y):
 
 :Parameters:
 
-    x : array-like
-        May be updated in place and should not be used again.
+    x: array-like
+       May be updated in place and should not be used again.
 
-    y : array-like
-        Will not be updated in place.
+    y: array-like
+       Will not be updated in place.
 
 :Returns:
 
-    out : numpy array
+    out: `numpy.ndarray`
 
 '''
     if numpy_ma_isMA(x):
@@ -136,15 +151,15 @@ def pmin(x, y):
 
 :Parameters:
 
-    x : numpy array
-        May be updated in place and should not be used again.
+    x: `numpy.ndarray`
+       May be updated in place and should not be used again.
 
-    y : numpy array
-        Will not be updated in place.
+    y: `numpy.ndarray`
+       Will not be updated in place.
 
 :Returns:
 
-    out : numpy array
+    out: `numpy.ndarray`
 
 '''
     if numpy_ma_isMA(x):
@@ -202,11 +217,20 @@ def mask_where_too_few_values(Nmin, N, x):
         N = numpy_ma_array(N, mask=mask, copy=False, shrink=False)
         x = numpy_ma_array(x, mask=mask, copy=False, shrink=True)
 
-    return N, x
+    return asanyarray(N, x)
 #--- End: def
 
 def double_precision(a):
-    '''
+    '''Convert the input array to double precision.
+
+:Parameters:
+
+    a: `numpy.ndarray`
+
+:Returns:
+
+    out: `numpy.ndarray`
+
 '''
     char = a.dtype.char
     if char == 'f':
@@ -215,12 +239,7 @@ def double_precision(a):
         newtype = int
     else:
         return a
-#    print 'DCH a.shape, a.dtype =',a.shape, a.dtype, newtype
-#    try:
-#        print 'a[10, 10, 10, 10] =',a[10, 10, 10, 10]
-#    except:
-#        pass
-
+    
     if numpy_ma_isMA(a):
         return a.astype(newtype)
     else:
@@ -261,7 +280,7 @@ axis.
         # numpy.float64)
         amax = numpy_asanyarray(amax)
 
-    return N, amax
+    return asanyarray(N, amax)
 #--- End: def
 
 def max_fpartial(out, out1=None):
@@ -273,7 +292,7 @@ def max_fpartial(out, out1=None):
         amax = pmax(amax, amax1)
     #--- End: if
 
-    return N, amax
+    return asanyarray(N, amax)
 #--- End: def
 
 def max_ffinalise(out, sub_samples=None):
@@ -296,30 +315,25 @@ axis.
 
 :Parameters:
 
-    a : numpy array_like
+    a: numpy array_like
         Input array
 
-    axis : int, optional
+    axis: `int`, optional
         Axis along which to operate. By default, flattened input is
         used.
 
-    masked : bool
+    masked: `bool`
 
 :Returns:
 
-    out : 2-tuple of numpy arrays
+    out: 2-tuple of `numpy.ndarray`
         The sample sizes and the minima.
      
 '''
     N    = sample_size_f(a, axis=axis, masked=masked)
     amin = numpy_amin(a, axis=axis)
 
-    if not numpy_ndim(amin):
-        # Make sure that we have a numpy array (as opposed to, e.g. a
-        # numpy.float64)
-        amin = numpy_asanyarray(amin)
-
-    return N, amin
+    return asanyarray(N, amin)
 #--- End: def
 
 def min_fpartial(out, out1=None):
@@ -333,7 +347,7 @@ def min_fpartial(out, out1=None):
         amin = pmin(amin, amin1)
     #--- End: if
 
-    return N, amin
+    return asanyarray(N, amin)
 #--- End: def
 
 def min_ffinalise(out, sub_samples=None):
@@ -355,28 +369,25 @@ The weighted average along the specified axes.
 
 :Parameters:
 
-    a : array-like
+    a: array-like
         Input array. Not all missing data
 
-    axis : int, optional
+    axis: `int`, optional
         Axis along which to operate. By default, flattened input is
         used.
 
-    weights : array-like, optional
+    weights: array-like, optional
 
-    masked : bool, optional
-
-    kwargs : ignored
+    masked: `bool`, optional
 
 :Returns:
 
-    out : tuple
+    out: `tuple`
         3-tuple.
 
 '''
-#    print 'DCH in mean_f'
     a = double_precision(a)
-
+    
     if masked:
         average = numpy_ma_average
     else:
@@ -392,8 +403,10 @@ The weighted average along the specified axes.
         N = sw.copy()
     else:
         N = sample_size_f(a, axis=axis, masked=masked)
+        
+#    (N, avg, sw) = asanyarray(N, avg, sw)
 
-    return N, avg, sw
+    return asanyarray(N, avg, sw)
 #--- End: def
 
 def mean_fpartial(out, out1=None):
@@ -416,13 +429,14 @@ def mean_fpartial(out, out1=None):
         sw  = psum(sw, sw1)
     #--- End: if
 
-    return N, avg, sw
+    return asanyarray(N, avg, sw)
 #--- End: def
 
 def mean_ffinalise(out, sub_samples=None):
     '''
 
-    sub_samples: `bool`, optional
+    sub_samples: optional
+        Ignored.
 
 :Returns:
 
@@ -476,7 +490,7 @@ axis=axis), numpy.amax(a, axis=axis))``
         amin = numpy_asanyarray(amin)
         amax = numpy_asanyarray(amax)
 
-    return N, amin, amax
+    return asanyarray(N, amin, amax)
 #--- End: def
 
 def mid_range_fpartial(out, out1=None):
@@ -492,7 +506,7 @@ def mid_range_fpartial(out, out1=None):
         amax = pmax(amax, amax1)
     #--- End: if
 
-    return N, amin, amax
+    return asanyarray(N, amin, amax)
 #--- End: def
 
 def mid_range_ffinalise(out, sub_samples=None):
@@ -545,7 +559,7 @@ Absolute difference between maximum and minimum
     N, amin, amax = out
 
     amax = double_precision(amax)
-
+  
     amax -= amin
       
     return mask_where_too_few_values(1, N, amax)
@@ -573,7 +587,7 @@ def sample_size_f(a, axis=None, masked=False):
             N[...] = shape[axis]
     #--- End: if
 
-    return N
+    return asanyarray(N)
 #--- End: def
 
 def sample_size_fpartial(N, out1=None):
@@ -592,7 +606,7 @@ def sample_size_fpartial(N, out1=None):
         N1 = out1
         N = psum(N, N1)
 
-    return N
+    return asanyarray(N)
 #--- End: def
 
 def sample_size_ffinalise(N, sub_samples=None):
@@ -611,7 +625,7 @@ def sample_size_ffinalise(N, sub_samples=None):
         A 2-tuple containing *N* twice.
 
 '''
-    return N, N
+    return asanyarray(N, N)
 #--- End: def
 
 #---------------------------------------------------------------------
@@ -643,14 +657,14 @@ axis=axis),)``
 
 '''
     a = double_precision(a)
-
+    
     N    = sample_size_f(a, axis=axis, masked=masked)
     asum = a.sum(axis=axis)
 
     if not numpy_ndim(asum):
         asum = numpy_asanyarray(asum)
 
-    return N, asum
+    return asanyarray(N, asum)
 #--- End: def
 
 def sum_fpartial(out, out1=None):
@@ -665,7 +679,7 @@ def sum_fpartial(out, out1=None):
         asum = psum(asum, asum1)
     #--- End: if
 
-    return N, asum
+    return asanyarray(N, asum)
 #--- End: def
 
 def sum_ffinalise(out, sub_samples=None):
@@ -687,12 +701,14 @@ def sw_f(a, axis=None, masked=False, weights=None, N=None,
         N = sample_size_f(a, axis=axis, masked=masked)
 
     if weights is not None:
+        weights = double_precision(weights)
+
         if weights.ndim < a.ndim:
             weights = broadcast_array(weights, a.shape)
 
         if masked:
             weights = numpy_ma_array(weights, mask=a.mask, copy=False)
-
+            
         if sum_of_squares:            
             weights = weights * weights
 
@@ -703,30 +719,8 @@ def sw_f(a, axis=None, masked=False, weights=None, N=None,
     else:
         sw = N.copy()
 
-    return (N, sw)
+    return asanyarray(N, sw)
 #--- End: def
-#def sw_f(a, axis=None, masked=False, weights=None):
-#    '''
-#'''
-#    N = sample_size_f(a, axis=axis, masked=masked)
-#
-#    if weights is not None:
-#        weights = double_precision(weights)
-#
-#        if weights.ndim < a.ndim:
-#            weights = broadcast_array(weights, a.shape)
-#
-#        if masked:
-#            weights = numpy_ma_array(weights, mask=a.mask, copy=False)
-#
-#        sw = weights.sum(axis=axis)
-#        if not numpy_ndim(sw):
-#            sw = numpy_asanyarray(sw)
-#    else:
-#        sw = N.copy()
-#
-#    return N, sw
-##--- End: def
 
 sw_fpartial  = sum_fpartial
 sw_ffinalise = sum_ffinalise
@@ -734,30 +728,7 @@ sw_ffinalise = sum_ffinalise
 #---------------------------------------------------------------------
 # Sum of squares of weights
 #---------------------------------------------------------------------
-#def sw2_f(a, axis=None, masked=False, weights=None):
-#    '''
-#'''
-#    N = sample_size_f(a, axis=axis, masked=masked)
-#
-#    if weights is not None:
-#        weights = double_precision(weights)
-#
-#        if weights.ndim < a.ndim:
-#            weights = broadcast_array(weights, a.shape)
-#            
-#        if masked:                    
-#            weights = numpy_ma_array(weights, mask=a.mask, copy=False)
-#
-#        sw2 = (weights*weights).sum(axis=axis)
-#        if not numpy_ndim(sw2):
-#            sw2 = numpy_asanyarray(sw2)
-#    else:
-#        sw2 = N.copy()
-#            
-#    return N, sw2
-##--- End: def
-
-sw2_f         = functools_partial(sw_f, sum_of_squares=True)
+sw2_f = functools_partial(sw_f, sum_of_squares=True)
 sw2_fpartial  = sum_fpartial
 sw2_ffinalise = sum_ffinalise
 
@@ -770,36 +741,27 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=0):
 :Return:
     out: `tuple`
 
-''' 
+'''
+    # Make sure that a is double precision
+    a = double_precision(a)
+    
     weighted = weights is not None
 
-   
-#    # ----------------------------------------------------------------
-#    # Find the minimum and maximum values of the weights if required
-#    # ----------------------------------------------------------------
-#    if not f and weights is not None and ddof:
-#        if weights.ndim <= 1:
-#            # Weights are 1-d
-#            wmin = weights.min()
-#            wmax = weights.max()
-#        else:
-#            # Weights have the same shape as a
-#            wmin = weights.min(axis=axis)
-#            wmax = weights.max(axis=axis)
-#    else:
-#        wmin  = None
-#        wmax  = None
-
     # ----------------------------------------------------------------
     # Methods:
     #
     # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
     # https://en.wikipedia.org/wiki/Weighted_arithmetic_mean#Weighted_sample_variance
     # ----------------------------------------------------------------
+
+    # Calculate N   = number of data points
+    # Calculate avg = mean of data
+    # Calculate V1  = sum of weights
     N, avg, V1 = mean_f(a, weights=weights, axis=axis, masked=masked)
 
+    # Calculate V2 = sum of squares of weights
     if weighted and ddof == 1:
-        N, V2 = sw2_f(a, axis=axis, masked=masked, weights=weights, N=N)        
+        N, V2 = sw2_f(a, axis=axis, masked=masked, weights=weights, N=N)
     else:
         V2 = None
 
@@ -831,70 +793,11 @@ def var_f(a, axis=None, weights=None, masked=False, ddof=0):
         shape = avg.shape        
         avg = avg.reshape(shape[:axis] + shape[axis+1:])
 
-    if not numpy_ndim(var):
-        var = numpy_asanyarray(var)
+    (N, var, avg, V1, V2) = asanyarray(N, var, avg, V1, V2)
 
     return (N, var, avg, V1, V2, ddof, weighted)
 #--- End: def
 
-#    # ----------------------------------------------------------------
-#    # Find the minimum and maximum values of the weights if required
-#    # ----------------------------------------------------------------
-#    if not f and weights is not None and ddof:
-#        if weights.ndim <= 1:
-#            # Weights are 1-d
-#            wmin = weights.min()
-#            wmax = weights.max()
-#        else:
-#            # Weights have the same shape as a
-#            wmin = weights.min(axis=axis)
-#            wmax = weights.max(axis=axis)
-#    else:
-#        wmin  = None
-#        wmax  = None
-#
-#    # ----------------------------------------------------------------
-#    # Methods:
-#    #
-#    # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
-#    # http://en.wikipedia.org/wiki/Weighted_mean#Weighted_sample_variance
-#    # ----------------------------------------------------------------
-#    N, avg, sw = mean_f(a, weights=weights, axis=axis, masked=masked)
-# 
-#    if axis is not None and avg.size > 1:
-#        # We collapsed over a single axis and the array has 2 or more
-#        # axes, so add an extra size 1 axis to the mean so that
-#        # broadcasting works when we calculate the variance.
-#        reshape_avg = True
-#        if masked:
-#            expand_dims = numpy_ma_expand_dims
-#        else:
-#            expand_dims = numpy_expand_dims
-#
-#        avg = expand_dims(avg, axis)
-#    else:
-#        reshape_avg = False
-#
-#    var  = a - avg
-#    var *= var
-#
-#    if masked:
-#        average = numpy_ma_average
-#    else:
-#        average = numpy_average
-#
-#    var = average(var, axis=axis, weights=weights)
-#    
-#    if reshape_avg:
-#        shape = avg.shape        
-#        avg = avg.reshape(shape[:axis] + shape[axis+1:])
-#
-#    if not numpy_ndim(var):
-#        var = numpy_asanyarray(var)
-#
-#    return N, var, avg, sw, ddof, f, wmin, wmax
-#--- End: def
-
 def var_fpartial(out, out1=None):
     '''https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
 
@@ -940,50 +843,11 @@ def var_fpartial(out, out1=None):
             V2 = psum(V2, V2b)
     #--- End: def
 
+    (N, var, avg, V1, V2) = asanyarray(N, var, avg, V1, V2)
+
     return (N, var, avg, V1, V2, ddof, weighted)
 #--- End: def
-#def var_fpartial(out, out1=None):
-#    '''
-#'''
-#    print 'DCH var_fpartial 1'
-#    N, var, avg, sw, ddof, f, wmin, wmax = out
-#
-#    if out1 is None:
-#        print 'DCH var_fpartial 2'
-#        # ------------------------------------------------------------
-#        # var = sw(var+avg**2)
-#        # avg = sw*avg
-#        # ------------------------------------------------------------
-#        var += avg*avg
-#        var *= sw 
-#        avg *= sw 
-#    else:       
-#        print 'DCH var_fpartial 3'
-#        # ------------------------------------------------------------
-#        # var = var + sw1(var1+avg1**2)
-#        # avg = avg + sw1*avg1
-#        # sw  = sw + sw1
-#        # ------------------------------------------------------------
-#        N1, var1, avg1, sw1, ddof, f, wmin1, wmax1 = out1
-#
-#        N = psum(N, N1)
-#        
-#        var1 += avg1*avg1
-#        var1 *= sw1
-#        avg1 *= sw1
-#
-#        var = psum(var, var1)
-#        avg = psum(avg, avg1)
-#        sw  = psum(sw , sw1)
-#
-#        if wmin is not None:
-#            wmin = pmin(wmin, wmin1)
-#            wmax = pmax(wmax, wmax1)
-#    #--- End: def
-#
-#    print 'DCH var_fpartial END'
-#    return N, var, avg, sw, ddof, f, wmin, wmax
-##--- End: def
+
 def var_ffinalise(out, sub_samples=None):
     '''
 https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
@@ -991,6 +855,9 @@ https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
     (N, var, avg, V1, V2, ddof, weighted) = out
 
     N, var = mask_where_too_few_values(max(2, ddof+1), N, var)
+    N, V1  = mask_where_too_few_values(max(2, ddof+1), N, V1)
+    if V2 is not None:
+        N, V2 = mask_where_too_few_values(max(2, ddof+1), N, V2)
 
     if sub_samples:
         # ----------------------------------------------------------------
@@ -1021,7 +888,7 @@ https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
             # The unweighted variance with N-ddof degrees of freedom is
             # [V1/(V1-ddof)]*var. In this case V1 equals the sample size,
             # N. ddof=1 provides an unbiased estimator of the variance of
-            # a hypothetical infinite population.            
+            # a hypothetical infinite population.
             V1 /= V1 - ddof
             var *= V1
     elif ddof == 1:
@@ -1036,173 +903,11 @@ https://en.wikipedia.org/wiki/Pooled_variance#Population-based_statistics
         var /= V1
     elif ddof:
         raise ValueError(
-"Can only calculate a weighted variance with 0 or 1 delta degrees of freedom: ddof={}".format(
-    ddof))
+"Can only calculate a weighted variance with a delta degrees of freedom (ddof) of 0 or 1: ddof={}".format(ddof))
 
-
-#    if ddof:
-#        if f:
-#            sw *= f
-#        elif wmin is not None:
-#           # ---------------------------------------------------------
-#           # The global variance is weighted and needs to be
-#           # calculated with greater than 0 delta degrees of
-#           # freedom. The sum of weights (sw) needs to be adjusted:
-#           #
-#           # sw = f*sw (approximately!)
-#           # 
-#           # where f = smallest positive number whose products with
-#           #           the smallest and largest weights and the sum of
-#           #           weights are all integers
-#           # ---------------------------------------------------------
-#           wmin = wmin.astype(float)
-#           wmax = wmax.astype(float)
-#           sw   = sw.astype(float)
-#           
-#           wmax /= wmin
-#           sw   /= wmin
-#           
-#           if (not numpy_allclose(wmax, wmax.astype(int), rtol=1e-05, atol=1e-08) or
-#               not numpy_allclose(sw  , sw.astype(int)  , rtol=1e-05, atol=1e-08)):
-#           
-#               m = numpy_zeros(wmax.shape, dtype=int)            
-#               n = 2
-#               while True:
-#                   nwmax = n*wmax
-#                   nsw   = n*sw
-#                   ccc = (m == 0)
-#                   ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
-#                   ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
-#                   m = numpy_where(ccc, n, m)
-#                   if m.min():
-#                       # Every element of m has been set (to an integer
-#                       # greater than 1), so we are done.
-#                       break                
-#                   
-#                   # Some elements of m have not been set, so try the
-#                   # next multiplier.
-#                   n += 1
-#               #--- End: while
-#               sw *= m
-#           #--- End: if
-#        #--- End: if
-#    
-#        # ------------------------------------------------------------
-#        # Adjust the variance for fewer than sw degrees of freedom:
-#        #
-#        # var = var*sw/(sw-ddof)
-#        # ------------------------------------------------------------
-#        var *= sw
-#        sw -= ddof
-#        var /= sw
-    #--- End: if
-
-    return N, var
+    return asanyarray(N, var)
 #--- End: def
 
-#def var_ffinalise(out, sub_samples=None):
-#    '''
-#:Parameters:
-#
-#    out: 8-tuple of `numpy.ndarray`
-#
-#    sub_samples: `bool`, optional
-#
-#:Returns:
-#
-#    out: 2-tuple of `numpy.ndarray`
-#
-#    '''
-#    N, var, avg, sw, ddof, f, wmin, wmax = out
-#
-#    N, var = mask_where_too_few_values(max(2, ddof+1), N, var)
-#
-#    if sub_samples:
-#        # ----------------------------------------------------------------
-#        # The global biased variance = {[SUM(psw(pv+pm**2)]/sw} - m**2        
-#        # 
-#        #   where psw = partial sum of weights
-#        #         pv  = partial biased variance 
-#        #         pm  = partial mean            
-#        #         sw  = global sum of weights
-#        #         m   = global mean             
-#        #
-#        # Currently: var = SUM(psw(pv+pm**2)
-#        #            avg = sw*m
-#        #
-#        # http://en.wikipedia.org/wiki/Standard_deviation#Population-based_statistics
-#        # ----------------------------------------------------------------
-#        avg /= sw
-#        avg *= avg
-#        var /= sw
-#        var -= avg
-#    #--- End: if
-#
-#    # ----------------------------------------------------------------
-#    # var is now the global variance with sw degrees of freedom
-#    # ----------------------------------------------------------------
-#    if ddof:
-#        print 'DCH in ddof'
-#        if f:
-#            sw *= f
-#        elif wmin is not None:
-#           # ---------------------------------------------------------
-#           # The global variance is weighted and needs to be
-#           # calculated with greater than 0 delta degrees of
-#           # freedom. The sum of weights (sw) needs to be adjusted:
-#           #
-#           # sw = f*sw (approximately!)
-#           # 
-#           # where f = smallest positive number whose products with
-#           #           the smallest and largest weights and the sum of
-#           #           weights are all integers
-#           # ---------------------------------------------------------
-#           wmin = wmin.astype(float)
-#           wmax = wmax.astype(float)
-#           sw   = sw.astype(float)
-#           
-#           wmax /= wmin
-#           sw   /= wmin
-#           
-#           if (not numpy_allclose(wmax, wmax.astype(int), rtol=1e-05, atol=1e-08) or
-#               not numpy_allclose(sw  , sw.astype(int)  , rtol=1e-05, atol=1e-08)):
-#           
-#               m = numpy_zeros(wmax.shape, dtype=int)            
-#               n = 2
-#               while True:
-#                   nwmax = n*wmax
-#                   nsw   = n*sw
-#                   ccc = (m == 0)
-#                   ccc &= numpy.isclose(nwmax, nwmax.astype(int), rtol=1e-05, atol=1e-08)
-#                   ccc &= numpy.isclose(nsw  , nsw.astype(int)  , rtol=1e-05, atol=1e-08)
-#                   m = numpy_where(ccc, n, m)
-#                   print 'DCH m.min() =', m.min()
-#                   if m.min():
-#                       # Every element of m has been set (to an integer
-#                       # greater than 1), so we are done.
-#                       break                
-#                   
-#                   # Some elements of m have not been set, so try the
-#                   # next multiplier.
-#                   n += 1
-#               #--- End: while
-#               sw *= m
-#           #--- End: if
-#        #--- End: if
-#    
-#        # ------------------------------------------------------------
-#        # Adjust the variance for fewer than sw degrees of freedom:
-#        #
-#        # var = var*sw/(sw-ddof)
-#        # ------------------------------------------------------------
-#        var *= sw
-#        sw -= ddof
-#        var /= sw
-#    #--- End: if
-#
-#    return N, var
-##--- End: def
-
 #---------------------------------------------------------------------
 # Standard deviation
 #---------------------------------------------------------------------
@@ -1214,17 +919,17 @@ def sd_ffinalise(out, sub_samples=None):
 
 :Parameters:
 
-    out: `tuple`
+    out : tuple
         A 2-tuple
 
-    sub_samples: *optional*
+    sub_samples : *optional*
         Ignored.
 
 
 '''
     N, sd = var_ffinalise(out, sub_samples)
-
+    
     sd **= 0.5
     
-    return N, sd
+    return asanyarray(N, sd)
 #--- End: def
