@@ -1,5 +1,5 @@
 import re
-
+#
 from operator  import mul
 from json      import loads as json_loads
 from ast       import literal_eval as ast_literal_eval
@@ -127,9 +127,11 @@ ancillaries, field ancillaries).
 
     g = {'compression'   : {},
          'new_dimensions': {},
+         'promoted'      : [],
          'cfa'           : False,
          'chunk'         : chunk,
          '_debug'        : _debug,
+         'formula_terms' : {},
     }
     
     compression = {}
@@ -144,15 +146,18 @@ ancillaries, field ancillaries).
             "Can't read: Bad parameter value: field={!r}".format(field))
            
     if 'all' in field:
-        field = set(('domain_ancillary', 'field_ancillary', 'dimension',
-                     'auxiliary', 'measure'))
+        field = set(('domain_ancillary', 'field_ancillary', 'dimension_coordinate',
+                     'auxiliary_coordinate', 'cell_measure'))
+
 
     filename = abspath(filename)
 
+    g['field']    = field
     g['filename'] = filename
     
     # Read the netCDF file 
     nc = _open_netcdf_file(filename, 'r')
+    g['nc'] = nc
 
     if _debug:
         print 'Input netCDF dataset =',nc
@@ -300,12 +305,12 @@ ancillaries, field ancillaries).
 
             if ncvar in variables:
 
-                if 'dimension' in field:
+                if 'dimension_coordinate' in field:
                     # Add the dimension coordinate to the set of
                     # top-level fields, so that it doesn't get demoted
                     # if the auxiliary coordinate is also in a
                     # coordinate reference.
-                    pass
+                    g['promoted'].append(ncvar)
                 else:
                     # Do not promote a dimension coordinate to also
                     # appear as a top-level field
@@ -336,25 +341,47 @@ ancillaries, field ancillaries).
 "WARNING: Missing bounds variable {0!r} in {1}".format(bounds, filename))
                 #--- End: for
 
+
+                # Remove domain ancillaries (unless they have been
+                # promoted) and their bounds.
                 if 'formula_terms' in attributes[ncvar]:
-                    formula_terms = re.split('\s+|\s*:\s+',
-                                             attributes[ncvar]['formula_terms'])
-                    
-                    for var in formula_terms[1::2]:
-                        # Skip terms which are in the list but not in the file
-                        if var not in nc.variables:
-                            continue
-                        if _ncdimensions(nc, var, g=g):
-                            if 'domain_ancillary' not in field:
-                                # Do not promote a domain ancillary to
-                                # also appear as a top-level field
-                                variables.discard(var)
-                        else:
-                            # Value is a scalar
-                            if 'reference' not in field:
-                                # Do not promote a parameter to also
-                                # appear as a top-level field
-                                variables.discard(var)
+                    formula_terms = attributes[ncvar]['formula_terms']
+                    if _debug:
+                        print '        Has formula_terms'
+                            
+                    _formula_terms_variables(ncvar, formula_terms,
+                                             variables, coord=True, g=g)
+    
+                    bounds = attributes[ncvar].get('bounds', None)
+                    if bounds is not None and 'formula_terms' in attributes[bounds]:
+                        bounds_formula_terms = attributes[bounds]['formula_terms']
+                        
+                        _formula_terms_variables(ncvar,
+                                                 bounds_formula_terms,
+                                                 variables,
+                                                 bounds=True, g=g)
+                #--- End: if
+    
+
+#                if 'formula_terms' in attributes[ncvar]:
+#                    formula_terms = re.split('\s+|\s*:\s+',
+#                                             attributes[ncvar]['formula_terms'])
+#                    
+#                    for var in formula_terms[1::2]:
+#                        # Skip terms which are in the list but not in the file
+#                        if var not in nc.variables:
+#                            continue
+#                        if _ncdimensions(nc, var, g=g):
+#                            if 'domain_ancillary' not in field:
+#                                # Do not promote a domain ancillary to
+#                                # also appear as a top-level field
+#                                variables.discard(var)
+#                        else:
+#                            # Value is a scalar
+#                            if 'domain_ancillary' not in field:
+#                                # Do not promote a parameter to also
+#                                # appear as a top-level field
+#                                variables.discard(var)
             #--- End: if
 
             continue
@@ -367,12 +394,12 @@ ancillaries, field ancillaries).
             for aux in re.split('\s+|\s*,\s*', attributes[ncvar]['coordinates']):
                 if aux in variables:
                     
-                    if 'auxiliary' in field:
+                    if 'auxiliary_coordinate' in field:
                         # Add the auxiliary coordinate to the set of
                         # top-level fields, so that it doesn't get
                         # demoted if the auxiliary coordinate is also
                         # in a coordinate reference.
-                        pass
+                        g['promoted'].append(ncvar)
                     else:
                         # Do not promote an auxiliary coordinate to
                         # also appear as a top-level field
@@ -422,7 +449,7 @@ ancillaries, field ancillaries).
             variables.discard(attributes[ncvar]['grid_mapping'])
 
         # Remove cell measure variables (unless they have been promoted).
-        if 'measure' not in field and 'cell_measures' in attributes[ncvar]:
+        if 'cell_measure' not in field and 'cell_measures' in attributes[ncvar]:
             cell_measures = re.split('\s*(\w+):\s*',
                                      attributes[ncvar]['cell_measures'])
             for msr in cell_measures[2::2]:
@@ -794,6 +821,56 @@ def _parse_DSG_indexed_contiguous_compression(nc, ncvar,
     del g['compression'][sample_ncdimension][_compression_type['DSG_contiguous']]
 #--- End: def
 
+def _formula_terms_variables(ncvar, formula_terms, variables,
+                             coord=False, bounds=False, g=None):
+    '''
+:Parameters:
+
+    ncvar: `str`
+
+    formula_terms: `str`
+        A CF-netCDF formula_terms attribute.
+
+    variables: `set`
+    '''
+    g['formula_terms'].setdefault(ncvar, {'coord' : {},
+                                          'bounds': {}})
+    
+    formula_terms = re.split('\s+|\s*:\s+',formula_terms)
+
+    if bounds:
+        b = ' bounds'
+    else:
+        b = ''
+        
+    for name, term in zip(formula_terms[0::2],
+                          formula_terms[1::2]):
+        # Skip terms which are in the list but not in the file
+        if term not in g['nc'].variables:
+            continue
+        
+        if g['_debug']:
+            print '        Has domain ancillary{}: {}'.format(b, term)
+
+        if 'domain_ancillary' not in g['field']:
+            # Do not promote a domain ancillary to also appear as a
+            # top-level field
+            variables.discard(term)
+        else:
+            g['promoted'].append(term)
+            
+        if bounds and term not in g['formula_terms'][ncvar]['coord'].values():
+            # Do not promote a domain ancillary's bounds to also
+            # appear as a top-level field
+            variables.discard(term)
+            g['promoted'].append(term)
+
+        if coord:
+            g['formula_terms'][ncvar]['coord'][name] = term
+        elif bounds:
+            g['formula_terms'][ncvar]['bounds'][name] = term
+#--- End: def
+    
 def _create_Field(filename,
                   nc,
                   data_ncvar,
@@ -1070,6 +1147,9 @@ Create a field for a given netCDF variable.
     # Add coordinate references from formula_terms properties
     # ----------------------------------------------------------------
     for key, coord in f.coords().iteritems():
+        if data_ncvar in g['promoted']:
+            break
+        
         formula_terms = attributes[coord.ncvar].get('formula_terms', None)
         if formula_terms is None:
             # This coordinate doesn't have a formula_terms attribute
@@ -1087,23 +1167,28 @@ Create a field for a given netCDF variable.
             axes = [ncdim_to_axis[ncdim] for ncdim in anc_ncdimensions
                     if ncdim in ncdim_to_axis]    
             
-            if not axes:
-                # Variable is scalar => term is a parameter, not a
-                # DomainAncillary
-                if ncvar not in coordref_parameters:
-                    variable = _create_Variable(nc, ncvar, attributes, g=g)
-                    coordref_parameters[ncvar] = variable
-                continue
-
-            # Still here? Then the term is a DomainAncillary, not a
-            # parameter.
+#            if not axes:
+#                # Variable is scalar => term is a parameter, not a
+#                # DomainAncillary
+#                if ncvar not in coordref_parameters:
+#                    variable = _create_Variable(nc, ncvar, attributes, g=g)
+#                    coordref_parameters[ncvar] = variable
+#                continue
+#
+#            # Still here? Then the term is a DomainAncillary, not a
+#            # parameter.
             if ncvar in domain_ancillaries:
                 domain_anc = domain_ancillaries[ncvar][1].copy()
-            else:
+            else: 
+                bounds = g['formula_terms'][coord.ncvar]['bounds'].get(term)
+                if bounds == ncvar:
+                    bounds = None
+
                 domain_anc = _create_bounded_item(nc, ncvar, attributes, f,
                                                   domainancillary=True, g=g,
+                                                  bounds=bounds,
                                                   verbose=verbose)
-                domain_ancillaries[ncvar] = domain_anc
+#                domain_ancillaries[ncvar] = domain_anc
 
             # Insert domain ancillary
             da_key = f.insert_domain_anc(domain_anc, axes=axes, copy=False)
@@ -1114,9 +1199,9 @@ Create a field for a given netCDF variable.
             
         #--- End: for
 
-        _create_formula_terms_ref(f, key, coord, formula_terms,
-                                  domain_ancillaries, coordref_parameters)
-#                                  ncvar_to_key, coordref_parameters)
+        _create_formula_terms_ref(f, key, coord,
+                                  g['formula_terms'][coord.ncvar]['coord'],
+                                  domain_ancillaries, g=g)
     #--- End: for
 
     # ----------------------------------------------------------------
@@ -1211,7 +1296,7 @@ Create a field for a given netCDF variable.
 
 def _create_bounded_item(nc, ncvar, attributes, f, dimension=False,
                          auxiliary=False, domainancillary=False,
-                         g=None, verbose=False):
+                         bounds=None, g=None, verbose=False):
     '''Create a variable which might have bounds.
 
 :Parameters:
@@ -1249,6 +1334,9 @@ def _create_bounded_item(nc, ncvar, attributes, f, dimension=False,
 
     properties.pop('formula_terms', None)
 
+    if bounds is not None:
+        properties['bounds'] = bounds
+    
     ncbounds = properties.pop('bounds', None)
     if ncbounds is None:
         ncbounds = properties.pop('climatology', None)
@@ -1582,7 +1670,7 @@ def _create_grid_mapping_ref(f, grid_mapping, attributes, ncvar_to_key):
 #--- End: def
 
 def _create_formula_terms_ref(f, key, coord, formula_terms,
-                              domain_ancillaries, coordref_parameters):
+                              domain_ancillaries, g=None):
     '''
 
 :Parameters:
@@ -1593,12 +1681,12 @@ def _create_formula_terms_ref(f, key, coord, formula_terms,
 
     coord: `cf.Coordinate`
 
-    formula_terms: `list`
-        The formula_terms attribute value from the netCDF file.
+    formula_terms: `dict`
 
     domain_ancillaries: `dict`
 
     coordref_parameters: `dict`
+        Ignored.
 
 :Returns:
 
@@ -1608,21 +1696,22 @@ def _create_formula_terms_ref(f, key, coord, formula_terms,
     parameters  = {}
     ancillaries = {}
 
-    for term, ncvar in zip(formula_terms[0::2], formula_terms[1::2]):
-        if ncvar in domain_ancillaries:
-            # The term's value is a domain ancillary of the field, so
-            # we put its identifier into the coordinate reference.
-            ancillaries[term] = domain_ancillaries[ncvar][0]
+#    for term, ncvar in zip(formula_terms[0::2], formula_terms[1::2]):
+    for term, ncvar in formula_terms.iteritems():
+#        if ncvar in domain_ancillaries:
+        # The term's value is a domain ancillary of the field, so
+        # we put its identifier into the coordinate reference.
+        ancillaries[term] = domain_ancillaries[ncvar][0]
 
-        elif ncvar in coordref_parameters:
-            # The term's value is a parameter
-            parameters[term] = coordref_parameters[ncvar].copy()
+#        elif ncvar in coordref_parameters:
+#            # The term's value is a parameter
+#            parameters[term] = coordref_parameters[ncvar].copy()
     #--- End: for 
 
     coordref = CoordinateReference(name=coord.getprop('standard_name', None),
                                    crtype='formula_terms',
                                    coordinates=(key,),
-                                   parameters=parameters,
+#                                   parameters=parameters,
                                    ancillaries=ancillaries)
 
     f.insert_ref(coordref, copy=False)
