@@ -670,10 +670,10 @@ Evaluate the query operation for a given object.
 
 :Parameters:
 
-    x: object
+    x:
         See `evaluate`.
 
-    parent_attr: tuple
+    parent_attr: `tuple`
        
 
 :Returns:
