@@ -1,5 +1,5 @@
 from ..constants import _file_to_fh
-from ..functions import open_files_threshold_exceeded, close_one_file
+from ..functions import open_files_threshold_exceeded, close_one_file, abspath
 
 from .umread.umfile import File, UMFileException
 
@@ -26,6 +26,8 @@ is returned with an open file descriptor.
 :Examples:
 
     '''
+    filename = abspath(filename)
+
     f = _file_to_UM.get(filename)
 
     if f is not None:
