@@ -259,15 +259,6 @@ add_unit_alias("10 dB", None, "bel", "bels")
 # --------------------------------------------------------------------
 _netCDF4_netcdftime_utime = netCDF4.netcdftime.utime
 _datetime                 = netCDF4.netcdftime.datetime
-DateFromJulianDay         = netCDF4.netcdftime.DateFromJulianDay
-if netCDF4.__version__ <= '1.1.1':
-    _DateFromNoLeapDay = netCDF4.netcdftime._DateFromNoLeapDay
-    _DateFromAllLeap   = netCDF4.netcdftime._DateFromAllLeap
-    _DateFrom360Day    = netCDF4.netcdftime._DateFrom360Day
-else:
-    _DateFromNoLeapDay = netCDF4.netcdftime.netcdftime._DateFromNoLeapDay
-    _DateFromAllLeap   = netCDF4.netcdftime.netcdftime._DateFromAllLeap
-    _DateFrom360Day    = netCDF4.netcdftime.netcdftime._DateFrom360Day
 
 # --------------------------------------------------------------------
 # Aliases for netCDF4.netcdftime functions
@@ -2376,17 +2367,9 @@ handles units of months and years as defined by Udunits, ie. 1 year =
             # Convert years to days
             unit_string = unit_string.replace(units, 'days', 1)
             time_value = numpy_array(time_value)*365.242198781
-#        elif units == 'calendar_month':
-#            # Convert months to days
-#            unit_string = unit_string.replace(units, 'days', 1)
-#            time_value = numpy_array(time_value)*365.242198781/12
-#        elif units == 'calendar_year':
-#            # Convert months to days
-#            unit_string = unit_string.replace(units, 'days', 1)
-#            time_value = numpy_array(time_value)*365.242198781/12
-
 
         u = _netCDF4_netcdftime_utime(unit_string, self.calendar)        
+
         return u.num2date(time_value)
     #--- End: def
 
