@@ -1,10 +1,12 @@
 import datetime
-import os
-import itertools
-import time
-from operator import mul
-import unittest
 import inspect
+import itertools
+from operator import mul
+import os
+import sys
+import time
+import unittest
+
 
 import numpy
 
@@ -211,7 +213,7 @@ class DataTest(unittest.TestCase):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
         
-    def test_Data___setitem__(self):
+    def test_Data___setitem__(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -442,7 +444,6 @@ class DataTest(unittest.TestCase):
             d._asreftime(i=True)
             self.assertTrue(d.dtype == numpy.dtype(float))
             self.assertFalse(d._isdatetime())
-#            print "pmshape =", d._pmshape
 
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
@@ -676,12 +677,14 @@ class DataTest(unittest.TestCase):
                       ):
                 for i, j in zip(d.ndindex(), numpy.ndindex(d.shape)):
                     self.assertTrue(i == j)
+                #--- End: for
             #--- End: for
-#            print 'pmshape =', d._pmshape
+        #--- End: for
+
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
         
-    def test_Data_roll(self):
+    def test_Data_roll(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -751,7 +754,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
                 
-    def test_Data_transpose(self):
+    def test_Data_transpose(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -845,7 +848,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)   
     #--- End: def
 
-    def test_Data_BINARY_AND_UNARY_OPERATORS(self):
+    def test_Data_BINARY_AND_UNARY_OPERATORS(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1026,7 +1029,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
-    def test_Data_BROADCASTING(self):
+    def test_Data_BROADCASTING(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1062,7 +1065,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
-    def test_Data__collapse_SHAPE(self):
+    def test_Data__collapse_SHAPE(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1129,7 +1132,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
-    def test_Data_max_min_sum(self):
+    def test_Data_max_min_sum(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1179,7 +1182,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: for         
 
-    def test_Data_sum_of_weights_sum_of_weights2(self):
+    def test_Data_sum_of_weights_sum_of_weights2(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1346,7 +1349,7 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
-    def test_Data_sample_size(self):
+    def test_Data_sample_size(self):        
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
 
@@ -1470,13 +1473,9 @@ class DataTest(unittest.TestCase):
                 for h in ('var', 'sd'):
                     for axes in self.axes_combinations:
                         for ddof in (0, 1):
-#                            print '\nweighted masked', chunksize, pp, 'axes='+str(axes), 'ddof='+str(ddof), h
                             b = reshape_array(self.ma, axes)
                             v = reshape_array(self.mw, axes)
 
-#                            print ' v.sum(<) =', v.sum()
-#                            print ' x.sum() =', x.array.sum()
-                            
                             not_enough_data = numpy.ma.count(b, axis=-1) <= ddof
 
                             avg = numpy.ma.average(b, axis=-1, weights=v)
@@ -1485,7 +1484,6 @@ class DataTest(unittest.TestCase):
                                 
                             b, V1 = numpy.ma.average((b-avg)**2, axis=-1, weights=v,
                                                      returned=True)
-#                            print 'V1.sum() =', V1.sum()
                             
                             b = numpy.ma.where(not_enough_data, numpy.ma.masked, b)
 
@@ -1494,16 +1492,13 @@ class DataTest(unittest.TestCase):
                                 # variance weighted with _reliability_ weights is
                                 # [V1**2/(V1**2-V2)]*var.
                                 V2 = numpy.asanyarray((v * v).sum(axis=-1))
-#                                print 'V2.sum() =', V2.sum()
                                 b *= (V1*V1/(V1*V1 - V2))                                
                             elif ddof == 0:
                                 pass
 
                             if h == 'sd':
                                 b **= 0.5
-#                            else:
-#                                print 'b.sum()=', b.sum()                                
-#                            print 'e', repr(x)
+
                             e = getattr(d, h)(axes=axes, weights=x,
                                               squeeze=True, ddof=ddof,
                                               _preserve_partitions=pp)
