@@ -119,7 +119,7 @@ class DSGTest(unittest.TestCase):
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.contiguous)
 
-            q = f.select1('specific')
+            q = f.select_field('specific')
             
             self.assertTrue(cf.functions._numpy_allclose(q.array, self.a))
         #--- End: for
@@ -134,7 +134,7 @@ class DSGTest(unittest.TestCase):
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.indexed)
 
-            q = f.select1('specific')
+            q = f.select_field('specific')
 
             self.assertTrue(cf.functions._numpy_allclose(q.array, self.a))
         #--- End: for
@@ -149,7 +149,7 @@ class DSGTest(unittest.TestCase):
             cf.CHUNKSIZE(chunksize)
             f = cf.read(self.indexed_contiguous)
 
-            q = f.select1('specific')
+            q = f.select_field('specific')
 
             self.assertTrue(cf.functions._numpy_allclose(q.array, self.b))
         #--- End: for
